@@ -5,8 +5,10 @@ import os
 from cvnn.utils import create_folder
 from tensorflow.keras.utils import get_custom_objects
 from cvnn.activations import act_dispatcher
+from cvnn.initializers import init_dispatcher
 
-get_custom_objects().update(act_dispatcher)     # Makes my activation functions usable with a simple string
+get_custom_objects().update(act_dispatcher)     # Makes my activation functions usable with a string
+get_custom_objects().update(init_dispatcher)
 
 
 def get_version() -> str:
